@@ -97,6 +97,10 @@ impl<N: Num> Point<N> {
         Size::new(other.first() - self.first(), other.second() - self.second())
     }
 
+    pub fn direction_to(self, other: Self) -> Size<f32> {
+        Line(self, other).direction()
+    }
+
     /// This is to allow creating a new Point, which wraps a different number type.
     ///
     /// For example `Point(1u8, 2u8)::to::<u32>()` creates a `Point(1u32, 2u32)`.
@@ -195,10 +199,17 @@ impl<O: Num, N: Num + ToRounded<O>> ToRounded<Point<O>> for Point<N> {
     }
 }
 
-impl<N: Num + ToSignedClamped> Point<N> {
+impl<N: Num + ToSignedClamped> Point<N>
+where
+    <N as ToSignedClamped>::Output: Signed,
+{
     pub fn to_signed_clamped(self) -> Point<<N as ToSignedClamped>::Output> {
         Point(self.x().to_signed_clamped(), self.y().to_signed_clamped())
     }
+
+    pub fn step_direction_to(self, other: Point<N>) -> Point<<N as ToSignedClamped>::Output> {
+        Line(self, other).step_direction()
+    }
 }
 
 impl<N: Num + Signed> Point<N> {
@@ -534,56 +545,130 @@ mod angle_to {
     use super::*;
     use ::assert_approx_eq::assert_approx_eq;
     use ::std::f32::consts::TAU;
+    use ::testcat::*;
 
-    #[test]
-    fn it_should_angle_to_zero_from_right() {
+    describe!("angle to zero", {
+        it!(
+            "should angle to zero from right",
+            test_angle_to_zero_from_right
+        );
+        it!(
+            "should angle to zero from above",
+            test_angle_to_zero_from_above
+        );
+        it!(
+            "should angle to zero from left",
+            test_angle_to_zero_from_left
+        );
+        it!(
+            "should angle to zero from below",
+            test_angle_to_zero_from_below
+        );
+    });
+
+    describe!("angle to point", {
+        it!(
+            "should angle to point from right",
+            test_angle_to_point_from_right
+        );
+        it!(
+            "should angle to point from above",
+            test_angle_to_point_from_above
+        );
+        it!(
+            "should angle to point from left",
+            test_angle_to_point_from_left
+        );
+        it!(
+            "should angle to point from below",
+            test_angle_to_point_from_below
+        );
+    });
+
+    fn test_angle_to_zero_from_right() {
         let point = Point(10.0, 0.0);
         assert_approx_eq!(point.angle_to(Point(0.0, 0.0)), 0.0);
     }
 
-    #[test]
-    fn it_should_angle_to_zero_from_above() {
+    fn test_angle_to_zero_from_above() {
         let point = Point(0.0, 10.0);
         assert_approx_eq!(point.angle_to(Point(0.0, 0.0)), TAU * 0.25);
     }
 
-    #[test]
-    fn it_should_angle_to_zero_from_left() {
+    fn test_angle_to_zero_from_left() {
         let point = Point(-10.0, 0.0);
         assert_approx_eq!(point.angle_to(Point(0.0, 0.0)), TAU * 0.5);
     }
 
-    #[test]
-    fn it_should_angle_to_zero_from_below() {
+    fn test_angle_to_zero_from_below() {
         let point = Point(0.0, -10.0);
         assert_approx_eq!(point.angle_to(Point(0.0, 0.0)), -TAU * 0.25);
     }
 
-    #[test]
-    fn it_should_angle_to_point_from_right() {
+    fn test_angle_to_point_from_right() {
         let origin = Point(5.0, 8.0);
         let point = Point(10.0, 0.0) + origin;
         assert_approx_eq!(point.angle_to(origin), 0.0);
     }
 
-    #[test]
-    fn it_should_angle_to_point_from_above() {
+    fn test_angle_to_point_from_above() {
         let origin = Point(5.0, 8.0);
         let point = Point(0.0, 10.0) + origin;
         assert_approx_eq!(point.angle_to(origin), TAU * 0.25);
     }
 
-    #[test]
-    fn it_should_angle_to_point_from_left() {
+    fn test_angle_to_point_from_left() {
         let origin = Point(5.0, 8.0);
         let point = Point(-10.0, 0.0) + origin;
         assert_approx_eq!(point.angle_to(origin), TAU * 0.5);
     }
 
-    #[test]
-    fn it_should_angle_to_point_from_below() {
+    fn test_angle_to_point_from_below() {
         let origin = Point(5.0, 8.0);
         let point = Point(0.0, -10.0) + origin;
         assert_approx_eq!(point.angle_to(origin), -TAU * 0.25);
     }
 }
+
+#[cfg(test)]
+mod step_direction_to {
+    use super::*;
+    use ::testcat::*;
+
+    it!(
+        "should return positive steps when stepping positively",
+        test_positive_step
+    );
+    it!(
+        "should return a step of 0 when both points on top of each other",
+        test_zero_step
+    );
+    it!(
+        "should return negative steps when stepping negatively",
+        test_negative_step
+    );
+
+    fn test_positive_step() {
+        let from: Point<i32> = Point(100, 200);
+        let to: Point<i32> = Point(333, 666);
+        let step = from.step_direction_to(to);
+
+        assert_eq!(step, Point(1, 1));
+    }
+
+    fn test_zero_step() {
+        let from: Point<i32> = Point(100, 200);
+        let to: Point<i32> = Point(100, 200);
+        let step = from.step_direction_to(to);
+
+        assert_eq!(step, Point(0, 0));
+    }
+
+    fn test_negative_step() {
+        let from: Point<i32> = Point(333, 666);
+        let to: Point<i32> = Point(-100, -200);
+        let step = from.step_direction_to(to);
+
+        assert_eq!(step, Point(-1, -1));
+    }
+}
